==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/persistenceassociations/impl/DelegationInComponentSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.persistenceassociations.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.component.C_CSet;
import io.ciera.tool.sql.ooaofooa.component.DelegationSet;
import io.ciera.tool.sql.ooaofooa.component.impl.C_CSetImpl;
import io.ciera.tool.sql.ooaofooa.component.impl.DelegationSetImpl;
import io.ciera.tool.sql.ooaofooa.persistenceassociations.DelegationInComponent;
import io.ciera.tool.sql.ooaofooa.persistenceassociations.DelegationInComponentSet;

import java.util.Arrays;
import java.util.List;


public class DelegationInComponentSetImpl extends InstanceSet<DelegationInComponentSet,DelegationInComponent> implements DelegationInComponentSet {

    // attributes
    @Override
    public void setComponent_Id( UniqueId ref_Component_Id ) throws XtumlException {
        for ( DelegationInComponent delegationincomponent : this ) delegationincomponent.setComponent_Id( ref_Component_Id );
    }
    @Override
    public void setDelegation_Id( UniqueId ref_Delegation_Id ) throws XtumlException {
        for ( DelegationInComponent delegationincomponent : this ) delegationincomponent.setDelegation_Id( ref_Delegation_Id );
    }


    // selections
    @Override
    public C_CSet R9002_C_C() throws XtumlException {
        C_CSet c_cset = new C_CSetImpl();
        for ( DelegationInComponent delegationincomponent : this ) c_cset.add( delegationincomponent.R9002_C_C() );
        return c_cset;
    }
    @Override
    public DelegationSet R9002_Delegation() throws XtumlException {
        DelegationSet delegationset = new DelegationSetImpl();
        for ( DelegationInComponent delegationincomponent : this ) delegationset.add( delegationincomponent.R9002_Delegation() );
        return delegationset;
    }


    @Override
    public DelegationInComponent nullElement() {
        return DelegationInComponentImpl.EMPTY_DELEGATIONINCOMPONENT;
    }

    @Override
    public DelegationInComponentSet emptySet() {
      return new DelegationInComponentSetImpl();
    }

    @Override
    public DelegationInComponentSet value() {
        return this;
    }

    @Override
    public List<DelegationInComponent> elements() {
        return Arrays.asList(toArray(new DelegationInComponent[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/persistenceassociations/impl/DelegationInComponentSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.persistenceassociations.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.component.C_CSet;
import io.ciera.tool.sql.ooaofooa.component.DelegationSet;
import io.ciera.tool.sql.ooaofooa.component.impl.C_CSetImpl;
import io.ciera.tool.sql.ooaofooa.component.impl.DelegationSetImpl;
import io.ciera.tool.sql.ooaofooa.persistenceassociations.DelegationInComponent;
import io.ciera.tool.sql.ooaofooa.persistenceassociations.DelegationInComponentSet;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class DelegationInComponentSetImpl extends InstanceSet<DelegationInComponentSet,DelegationInComponent> implements DelegationInComponentSet {

    public DelegationInComponentSetImpl() {
    }

    public DelegationInComponentSetImpl(Comparator<? super DelegationInComponent> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setDelegation_Id( UniqueId ref_Delegation_Id ) throws XtumlException {
        for ( DelegationInComponent delegationincomponent : this ) delegationincomponent.setDelegation_Id( ref_Delegation_Id );
    }
    @Override
    public void setComponent_Id( UniqueId ref_Component_Id ) throws XtumlException {
        for ( DelegationInComponent delegationincomponent : this ) delegationincomponent.setComponent_Id( ref_Component_Id );
    }


    // selections
    @Override
    public C_CSet R9002_C_C() throws XtumlException {
        C_CSet c_cset = new C_CSetImpl();
        for ( DelegationInComponent delegationincomponent : this ) c_cset.add( delegationincomponent.R9002_C_C() );
        return c_cset;
    }
    @Override
    public DelegationSet R9002_Delegation() throws XtumlException {
        DelegationSet delegationset = new DelegationSetImpl();
        for ( DelegationInComponent delegationincomponent : this ) delegationset.add( delegationincomponent.R9002_Delegation() );
        return delegationset;
    }


    @Override
    public DelegationInComponent nullElement() {
        return DelegationInComponentImpl.EMPTY_DELEGATIONINCOMPONENT;
    }

    @Override
    public DelegationInComponentSet emptySet() {
      return new DelegationInComponentSetImpl();
    }

    @Override
    public DelegationInComponentSet emptySet(Comparator<? super DelegationInComponent> comp) {
      return new DelegationInComponentSetImpl(comp);
    }

    @Override
    public DelegationInComponentSet value() {
        return this;
    }

    @Override
    public List<DelegationInComponent> elements() {
        return Arrays.asList(toArray(new DelegationInComponent[0]));
    }

}
